﻿--
-- Specialization for caseIH_mowerTT
-- by usxi7sd 01/2014

caseIH_mower = {};

function caseIH_mower.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Foldable, specializations);
end;

function caseIH_mower:load(xmlFile)	
	self.sj = {};
	self.sj.node = Utils.indexToObject( self.components, getXMLString(xmlFile, "vehicle.speedJoystick#node") );
	self.sj.rotF = math.rad( getXMLFloat(xmlFile, "vehicle.speedJoystick#rotFront") );
	self.sj.rotB = math.rad( getXMLFloat(xmlFile, "vehicle.speedJoystick#rotBack") );
	self.sj.rotT = 0;
	self.sj.rotC = 0;
	
	self.printFoldingError = 0;
	self.printTurnOnError = 0;
	
	self.tankfillParticleSystems = {};
    local psName = "vehicle.tankfillParticleSystem";
    Utils.loadParticleSystem(xmlFile, self.tankfillParticleSystems, psName, self.components, false, nil, self.baseDirectory)
    self.tankfillParticleSystemActive = false;
	
	self.fillLevelmom = self.fillLevel;
	self.particleyes = false;
	
	local fillLevelAlarm = getXMLString(xmlFile, "vehicle.fillLevelAlarm#file");
    if fillLevelAlarm ~= nil and fillLevelAlarm ~= "" then
		fillLevelAlarm = Utils.getFilename(fillLevelAlarm, self.baseDirectory);
		self.fillLevelAlarm = createSample("fillLevelAlarm");
		self.fillLevelAlarmEnabled = false;
		loadSample(self.fillLevelAlarm, fillLevelAlarm, false);
		self.fillLevelAlarmPitchOffset = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.fillLevelAlarm#pitchOffset"), 1);
		self.fillLevelAlarmVolume = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.fillLevelAlarm#volume"), 1);
		setSamplePitch(self.fillLevelAlarm, self.fillLevelAlarmPitchOffset);
    end;
	self.fillLevelpercent = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.fillLevelAlarm#warnpercent"), 3);
	self.warnLevel = self.capacity / 100 * self.fillLevelpercent;
end;

function caseIH_mower:delete()
	Utils.deleteParticleSystem(self.tankfillParticleSystems);
	if self.fillLevelAlarm ~= nil then
		delete(self.fillLevelAlarm);
		self.fillLevelAlarmEnabled = false;
    end;
end;

function caseIH_mower:readStream(streamId, connection)
end;
function caseIH_mower:writeStream(streamId, connection)
end;
function caseIH_mower:mouseEvent(posX, posY, isDown, isUp, button)
end;
function caseIH_mower:keyEvent(unicode, sym, modifier, isDown)
end;

function caseIH_mower:update(dt)
	if self:getIsActive() then
		if self.isClient then			
			local axisForward = 0;
			axisForward = InputBinding.getDigitalInputAxis(InputBinding.AXIS_MOVE_FORWARD_VEHICLE);
			if InputBinding.isAxisZero(axisForward) then
				axisForward = InputBinding.getAnalogInputAxis(InputBinding.AXIS_MOVE_FORWARD_VEHICLE)
			end;
			if axisForward < 0 then
				self.sj.rotT = -self.sj.rotF*axisForward;
			elseif axisForward > 0 then
				self.sj.rotT = self.sj.rotB*axisForward;
			else
				self.sj.rotT = 0;
			end;			
			if self.ESLimiter ~= nil and self.lastLevel ~= 0 and self:getIsActiveForInput(false) and not self:hasInputConflictWithSelection() then
				local percentage = self.ESLimiter.percentage;
				if InputBinding.isPressed(InputBinding.ESLimiter_PLUS) and percentage[self.lastLevel] < 100 then					
					self.sj.rotT = self.sj.rotF/2;
				elseif InputBinding.isPressed(InputBinding.ESLimiter_MINUS) and percentage[self.lastLevel] > 10 then
					self.sj.rotT = self.sj.rotB/2;
				end;
			end;			
			if self.sj.rotC < self.sj.rotT then
				self.sj.rotC = self.sj.rotC + dt/1000;
				if self.sj.rotC > self.sj.rotT then
					self.sj.rotC = self.sj.rotT;
				end;
			elseif self.sj.rotC > self.sj.rotT then
				self.sj.rotC = self.sj.rotC - dt/1000;
				if self.sj.rotC < self.sj.rotT then
					self.sj.rotC = self.sj.rotT;
				end;
			end;			
			setRotation( self.sj.node, self.sj.rotC, 0, 0 );			
		end;			
	
		if InputBinding.hasEvent(InputBinding.IMPLEMENT_EXTRA2) and self.isTurnedOn and self.foldAnimTime < 1 then           
			self.printFoldingError = self.time + 1800;
			self:setFoldDirection(0, false);
		end;
		if InputBinding.hasEvent(InputBinding.IMPLEMENT_EXTRA) and self.foldAnimTime == 1 then                              
			self.printTurnOnError = self.time + 1800;
			self:setIsTurnedOn(false);
		end;
		
	end;	
end;                                                  

function caseIH_mower:updateTick(dt)
	if self:getIsActive() then	
		if self.fillLevelmom < self.fillLevel then
			self.particleyes = true;
			self.fillLevelmom = self.fillLevel;
			else
			self.particleyes = false;
			self.fillLevelmom = self.fillLevel;
		end;
		
		if self.isTurnedOn and not self.useMowerWindrowDropAreas and self.fillLevel < self.capacity and self.fillLevel > 0 and self.particleyes then      
			self.tankfillParticleSystemActive = true;
			Utils.setEmittingState(self.tankfillParticleSystems, true);  
			else
			self.tankfillParticleSystemActive = false;
			Utils.setEmittingState(self.tankfillParticleSystems, false);  
		end;
	
		if self.isTurnedOn and self.fillLevel > (self.capacity - self.warnLevel) and not self.useMowerWindrowDropAreas then
            if not self.fillLevelAlarmEnabled and self:getIsActiveForSound() then     
                setSamplePitch(self.fillLevelAlarm, self.fillLevelAlarmPitchOffset);
                playSample(self.fillLevelAlarm, 0, self.fillLevelAlarmVolume, 0);
                self.fillLevelAlarmEnabled = true;
            end;
            else
            if self.fillLevelAlarmEnabled then                                        
                stopSample(self.fillLevelAlarm);
                self.fillLevelAlarmEnabled = false;
            end;
        end;		 
	end;
end;

function caseIH_mower:draw()	
	if self.printFoldingError > self.time then
		g_currentMission:addWarning(g_i18n:getText("TURNOFF_CHOPPER_FIRST"), 0.018, 0.033);		
	end;
	if self.printTurnOnError > self.time then
		g_currentMission:addWarning(g_i18n:getText("UNFOLD_CHOPPER_FIRST"), 0.018, 0.033);
	end;
end;

function caseIH_mower:onDeactivateSounds()
    if self.fillLevelAlarmEnabled then
        stopSample(self.fillLevelAlarm);
        self.fillLevelAlarmEnabled = false;
    end;
end;